@@ -12,7 +12,7 @@ use vars qw(
 ## Inheritance and Versioning ##
 
 @ISA     = qw( Exporter );
-$VERSION = '0.16';
+$VERSION = '0.17';
 
 ## General Definitions ##
 
@@ -107,6 +107,7 @@ sub new
         _support_capabilities  => TRUE,
         _support_mbgp          => TRUE,
         _support_as4           => FALSE,
+        _opaque_data           => undef,
         _open_callback         => undef,
         _established_callback  => undef,
         _keepalive_callback    => undef,
@@ -153,6 +154,9 @@ sub new
         elsif ( $arg =~ /^refreshcallback$/i ) {
             $this->{_refresh_callback} = $value;
         }
+        elsif ( $arg =~ /^opaquedata$/i ) {
+            $this->{_opaque_data} = $value;
+        }
         elsif ( $arg =~ /^refresh$/i ) {
             warnings::warnif(
                 'deprecated',
@@ -352,6 +356,14 @@ sub is_established
     return ( $this->transport->is_established );
 }
 
+sub opaque_data
+{
+    my ($this, $opaque_data) = @_;
+    my $old_value = $this->{_opaque_data};
+    $this->{_opaque_data} = $opaque_data if defined($opaque_data);
+    return ( $old_value );
+}
+
 sub set_open_callback
 {
     my ($this, $callback) = @_;
@@ -570,6 +582,7 @@ Net::BGP::Peer - Class encapsulating BGP-4 peering session state and functionali
         SupportCapabilities  => 1,
         SupportMBGP          => 1,
         SupportAS4           => 1,
+        OpaqueData           => $my_ref,
         OpenCallback         => \&my_open_callback,
         KeepaliveCallback    => \&my_keepalive_callback,
         UpdateCallback       => \&my_update_callback,
@@ -591,6 +604,8 @@ Net::BGP::Peer - Class encapsulating BGP-4 peering session state and functionali
     $this_as = $peer->this_as();
     $peer_id = $peer->peer_id();
     $peer_as = $peer->peer_as();
+    $my_ref  = $peer->opaque_data();
+    $my_ref  = $peer->opaque_data($new_ref);
 
     $i_will  = $peer->support_capabilities();
 
@@ -743,6 +758,14 @@ to TRUE (on the listening connection) whenever the appropriate OPEN capability
 is received.  Note that the B<SupportCapabilities> must be true for this to
 be sent.  This defaults to FALSE.
 
+=head2 OpaqueData
+
+This parameter is an optional scalar that will be kept as part of the
+B<Net::BGP::Peer> and can be queried by the callback routines when they
+receive a peer hashref - see B<opaque_data>. This allows extra data to be
+stored with the peer. The contents of this are completely ignored by
+B<Net::BGP::Peer>. This defaults to I<undef>.
+
 =head2 OpenCallback
 
 This parameter sets the callback function which is invoked when the
@@ -866,6 +889,15 @@ These are accessor methods for the corresponding constructor named parameters.
 They retrieve the values set when the object was created, but the values cannot
 be changed after object construction. Hence, they take no arguments.
 
+I<opaque_data()>
+
+    $peer->opaque_data();
+    $peer->opaque_data($new_ref);
+
+This method can be used to both query (no argument) or set (with an argument)
+the opaque data held with the peer object. The method returns the old opaque data
+scalar (which is the current value if not provided).
+
 I<is_established()>
 
 This accessor method returns true if the peer has a established transport
@@ -1022,7 +1054,7 @@ Net::BGP::Refresh, Net::BGP::Notification
 
 =head1 AUTHOR
 
-Stephen J. Scheck <code@neurosphere.com>
+Stephen J. Scheck <sscheck@cpan.org>
 
 =cut
 
